@@ -189,6 +189,10 @@ namespace facter { namespace facts {
         * The HuaweiOS operating system.
         */
         constexpr static char const* huawei = "HuaweiOS";
+       /**
+        * The PhotonOS operating system.
+        */
+        constexpr static char const* photon_os = "PhotonOS";
     };
 
 }}
